==> haskell-hls-explicit-record-fields-plugin-2.1.0.0-59-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-record-fields-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-record-fields-plugin
version:              2.1.0.0
visibility:           public
id:
    hls-explicit-record-fields-plugin-2.1.0.0-8Uog3XDfrDSKyvCENYG0lC

key:
    hls-explicit-record-fields-plugin-2.1.0.0-8Uog3XDfrDSKyvCENYG0lC

license:              BSD-3-Clause
maintainer:           berk.ozkutuk@tweag.io
author:               Berk Ozkutuk
synopsis:             Explicit record fields plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  0071bccaca8b80f47ab4f284c26736e2
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitFields
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-record-fields-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-record-fields-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-record-fields-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-record-fields-plugin
hs-libraries:
    HShls-explicit-record-fields-plugin-2.1.0.0-8Uog3XDfrDSKyvCENYG0lC

depends:
    base-4.17.2.1 containers-0.6.7 ghc-boot-th-9.4.8
    ghcide-2.1.0.0-7mveeBu1NdO3tDaPLTwSr0
    hls-graph-2.1.0.0-E0uwKa062XbErlHzLpQDMc
    hls-plugin-api-2.1.0.0-2mMBQBjk997A47exxFPkZd
    lens-5.3.1-57CGCDOUfQCLkJSlnZcVUR
    lsp-2.1.0.0-GxokUjVxBLy4j05JlhgdFg syb-0.7.3-Lap6GPARkRXCVbqA2faY6P
    text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-89DcpQLd7HI30AdGz5XyJk

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-record-fields-plugin/html/hls-explicit-record-fields-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-explicit-record-fields-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-explicit-record-fields-plugin-2.1.0.0-94-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-record-fields-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-record-fields-plugin
version:              2.1.0.0
visibility:           public
id:
    hls-explicit-record-fields-plugin-2.1.0.0-35CuIJZKOUOAVIt7GmLEKQ

key:
    hls-explicit-record-fields-plugin-2.1.0.0-35CuIJZKOUOAVIt7GmLEKQ

license:              BSD-3-Clause
maintainer:           berk.ozkutuk@tweag.io
author:               Berk Ozkutuk
synopsis:             Explicit record fields plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  9a622b6ee6fc5390973fb0c2df2b74ad
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitFields
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-record-fields-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-record-fields-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-record-fields-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-record-fields-plugin
hs-libraries:
    HShls-explicit-record-fields-plugin-2.1.0.0-35CuIJZKOUOAVIt7GmLEKQ

depends:
    base-4.17.2.1 containers-0.6.7 ghc-boot-th-9.4.8
    ghcide-2.1.0.0-EGobQkKgR8zaeADYgxOC5
    hls-graph-2.1.0.0-7LnpvrkjhrNH9iznMLZXCG
    hls-plugin-api-2.1.0.0-EfBvd6pBF3is65S9wzuFu
    lens-5.3.3-1zYcQilqoBK5EhYwkXjOnb
    lsp-2.1.0.0-4wEItkatDyfAFCzTPH6SAN syb-0.7.3-C5AaeelSWDKGvBUWTjIxkt
    text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-record-fields-plugin/html/hls-explicit-record-fields-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-explicit-record-fields-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
